@@ -12,13 +12,7 @@ class Checker:
         pass
 
 
-class SimpleChecker(Checker):
-    @staticmethod
-    def check(f: Path, **kwargs) -> Dict[str, str]:
-        return {"checksum": calculate_checksum(f)}
-
-
-class ConnectedChecker(Checker):
+class ChecksumChecker(Checker):
     @staticmethod
     def check(f: Path, connector: Any = None, **kwargs) -> Dict[str, str]:
         """Calculates checksum using method provided by the connector"""
